<img src="docs/source/pycromanager_banner.png" width="600">

`pycromanager` is a Python library for enabling microscope acquisition control and data analysis. It works together with [Micro-manager](https://micro-manager.org/) and [Micro-magellan](https://micro-manager.org/wiki/MicroMagellan).

Check out to the [documentation](https://pycro-manager.readthedocs.io/en/latest/) for an idea of the capabilities and how to get started.

Have a cool example of something you've done with `pycromanager` or an idea for improvement? Contributions/examples welcome!
